@@ -4,7 +4,7 @@ package Crypt::Noise;
 use strict;
 use warnings;
 
-use bignum;
+#use bignum;
 
 require Exporter;
 
@@ -19,6 +19,8 @@ use Digest::HMAC qw(hmac);
 use Crypt::KeyDerivation ':all';
 use Carp;
 
+our $VERSION = 0.011;
+
 #use Smart::Comments;
 
 our @ISA    = qw(Exporter);
